@@ -1,6 +1,5 @@
+"""The extension manager."""
 import importlib
-import sys
-import traceback
 
 from tornado.gen import multi
 from traitlets import Any, Bool, Dict, HasTraits, Instance, Unicode, default, observe
@@ -8,12 +7,7 @@ from traitlets import validate as validate_trait
 from traitlets.config import LoggingConfigurable
 
 from .config import ExtensionConfigManager
-from .utils import (
-    ExtensionMetadataError,
-    ExtensionModuleNotFound,
-    get_loader,
-    get_metadata,
-)
+from .utils import ExtensionMetadataError, ExtensionModuleNotFound, get_loader, get_metadata
 
 
 class ExtensionPoint(HasTraits):
@@ -28,22 +22,23 @@ class ExtensionPoint(HasTraits):
 
     @validate_trait("metadata")
     def _valid_metadata(self, proposed):
+        """Validate metadata."""
         metadata = proposed["value"]
         # Verify that the metadata has a "name" key.
         try:
             self._module_name = metadata["module"]
         except KeyError:
-            raise ExtensionMetadataError(
-                "There is no 'module' key in the extension's metadata packet."
-            )
+            msg = "There is no 'module' key in the extension's metadata packet."
+            raise ExtensionMetadataError(msg) from None
 
         try:
             self._module = importlib.import_module(self._module_name)
         except ImportError:
-            raise ExtensionModuleNotFound(
-                "The submodule '{}' could not be found. Are you "
-                "sure the extension is installed?".format(self._module_name)
+            msg = (
+                f"The submodule '{self._module_name}' could not be found. Are you "
+                "sure the extension is installed?"
             )
+            raise ExtensionModuleNotFound(msg) from None
         # If the metadata includes an ExtensionApp, create an instance.
         if "app" in metadata:
             self._app = metadata["app"]()
@@ -99,6 +94,7 @@ class ExtensionPoint(HasTraits):
         return self._module
 
     def _get_linker(self):
+        """Get a linker."""
         if self.app:
             linker = self.app._link_jupyter_server_extension
         else:
@@ -112,6 +108,7 @@ class ExtensionPoint(HasTraits):
         return linker
 
     def _get_loader(self):
+        """Get a loader."""
         loc = self.app
         if not loc:
             loc = self.module
@@ -163,6 +160,7 @@ class ExtensionPackage(HasTraits):
     enabled = Bool(False).tag(config=True)
 
     def __init__(self, *args, **kwargs):
+        """Initialize an extension package."""
         # Store extension points that have been linked.
         self._linked_points = {}
         super().__init__(*args, **kwargs)
@@ -175,11 +173,12 @@ class ExtensionPackage(HasTraits):
         self._extension_points = {}
         try:
             self._module, self._metadata = get_metadata(name)
-        except ImportError:
-            raise ExtensionModuleNotFound(
-                "The module '{name}' could not be found. Are you "
-                "sure the extension is installed?".format(name=name)
+        except ImportError as e:
+            msg = (
+                f"The module '{name}' could not be found ({e}). Are you "
+                "sure the extension is installed?"
             )
+            raise ExtensionModuleNotFound(msg) from None
         # Create extension point interfaces for each extension path.
         for m in self._metadata:
             point = ExtensionPoint(metadata=m)
@@ -192,7 +191,7 @@ class ExtensionPackage(HasTraits):
         return self._module
 
     @property
-    def version(self):
+    def version(self) -> str:
         """Get the version of this package, if it's given. Otherwise, return an empty string"""
         return getattr(self._module, "__version__", "")
 
@@ -214,20 +213,24 @@ class ExtensionPackage(HasTraits):
         return True
 
     def link_point(self, point_name, serverapp):
+        """Link an extension point."""
         linked = self._linked_points.get(point_name, False)
         if not linked:
             point = self.extension_points[point_name]
             point.link(serverapp)
 
     def load_point(self, point_name, serverapp):
+        """Load an extension point."""
         point = self.extension_points[point_name]
         return point.load(serverapp)
 
     def link_all_points(self, serverapp):
+        """Link all extension points."""
         for point_name in self.extension_points:
             self.link_point(point_name, serverapp)
 
     def load_all_points(self, serverapp):
+        """Load all extension points."""
         return [self.load_point(point_name, serverapp) for point_name in self.extension_points]
 
 
@@ -324,12 +327,19 @@ class ExtensionManager(LoggingConfigurable):
             return True
         # Raise a warning if the extension cannot be loaded.
         except Exception as e:
-            if self.serverapp.reraise_server_extension_failures:
+            if self.serverapp and self.serverapp.reraise_server_extension_failures:
                 raise
-            self.log.warning(e)
+            self.log.warning(
+                "%s | error adding extension (enabled: %s): %s",
+                extension_name,
+                enabled,
+                e,
+                exc_info=True,
+            )
         return False
 
     def link_extension(self, name):
+        """Link an extension by name."""
         linked = self.linked_extensions.get(name, False)
         extension = self.extensions[name]
         if not linked and extension.enabled:
@@ -337,36 +347,33 @@ class ExtensionManager(LoggingConfigurable):
                 # Link extension and store links
                 extension.link_all_points(self.serverapp)
                 self.linked_extensions[name] = True
-                self.log.info(f"{name} | extension was successfully linked.")
+                self.log.info("%s | extension was successfully linked.", name)
             except Exception as e:
-                if self.serverapp.reraise_server_extension_failures:
+                if self.serverapp and self.serverapp.reraise_server_extension_failures:
                     raise
-                self.log.warning(e)
+                self.log.warning("%s | error linking extension: %s", name, e, exc_info=True)
 
     def load_extension(self, name):
+        """Load an extension by name."""
         extension = self.extensions.get(name)
 
         if extension.enabled:
             try:
                 extension.load_all_points(self.serverapp)
             except Exception as e:
-                if self.serverapp.reraise_server_extension_failures:
+                if self.serverapp and self.serverapp.reraise_server_extension_failures:
                     raise
-                self.log.debug("".join(traceback.format_exception(*sys.exc_info())))
-                self.log.warning(
-                    "{name} | extension failed loading with message: {error}".format(
-                        name=name, error=str(e)
-                    )
-                )
+                self.log.warning("%s | extension failed loading with message: %s", name, e)
+                self.log.exception("%s | stack trace", name)
             else:
-                self.log.info(f"{name} | extension was successfully loaded.")
+                self.log.info("%s | extension was successfully loaded.", name)
 
     async def stop_extension(self, name, apps):
         """Call the shutdown hooks in the specified apps."""
         for app in apps:
-            self.log.debug(f'{name} | extension app "{app.name}" stopping')
+            self.log.debug("%s | extension app %r stopping", name, app.name)
             await app.stop_extension()
-            self.log.debug(f'{name} | extension app "{app.name}" stopped')
+            self.log.debug("%s | extension app %r stopped", name, app.name)
 
     def link_all_extensions(self):
         """Link all enabled extensions
@@ -394,3 +401,10 @@ class ExtensionManager(LoggingConfigurable):
                 for name, apps in sorted(dict(self.extension_apps).items())
             ]
         )
+
+    def any_activity(self):
+        """Check for any activity currently happening across all extension applications."""
+        for _, apps in sorted(dict(self.extension_apps).items()):
+            for app in apps:
+                if app.current_activity():
+                    return True
