@@ -11,27 +11,32 @@ try:
     from jupyter_client.jsonutil import json_default
 except ImportError:
     from jupyter_client.jsonutil import date_default as json_default
+
 from jupyter_client.kernelspec import NoSuchKernel
+from jupyter_core.utils import ensure_async
 from tornado import web
 
-from ...base.handlers import APIHandler
-from jupyter_server.utils import ensure_async
-from jupyter_server.utils import url_path_join
 from jupyter_server.auth import authorized
+from jupyter_server.utils import url_path_join
 
+from ...base.handlers import APIHandler
 
 AUTH_RESOURCE = "sessions"
 
 
 class SessionsAPIHandler(APIHandler):
+    """A Sessions API handler."""
+
     auth_resource = AUTH_RESOURCE
 
 
 class SessionRootHandler(SessionsAPIHandler):
+    """A Session Root API handler."""
+
     @web.authenticated
     @authorized
     async def get(self):
-        # Return a list of running sessions
+        """Get a list of running sessions."""
         sm = self.session_manager
         sessions = await ensure_async(sm.list_sessions())
         self.finish(json.dumps(sessions, default=json_default))
@@ -39,7 +44,7 @@ class SessionRootHandler(SessionsAPIHandler):
     @web.authenticated
     @authorized
     async def post(self):
-        # Creates a new session
+        """Create a new session."""
         # (unless a session already exists for the named session)
         sm = self.session_manager
 
@@ -91,7 +96,7 @@ class SessionRootHandler(SessionsAPIHandler):
                 status_msg = "%s not found" % kernel_name
                 self.log.warning("Kernel not found: %s" % kernel_name)
                 self.set_status(501)
-                self.finish(json.dumps(dict(message=msg, short_message=status_msg)))
+                self.finish(json.dumps({"message": msg, "short_message": status_msg}))
                 return
             except Exception as e:
                 raise web.HTTPError(500, str(e)) from e
@@ -103,10 +108,12 @@ class SessionRootHandler(SessionsAPIHandler):
 
 
 class SessionHandler(SessionsAPIHandler):
+    """A handler for a single session."""
+
     @web.authenticated
     @authorized
     async def get(self, session_id):
-        # Returns the JSON model for a single session
+        """Get the JSON model for a single session."""
         sm = self.session_manager
         model = await sm.get_session(session_id=session_id)
         self.finish(json.dumps(model, default=json_default))
@@ -172,7 +179,7 @@ class SessionHandler(SessionsAPIHandler):
     @web.authenticated
     @authorized
     async def delete(self, session_id):
-        # Deletes the session with given session_id
+        """Delete the session with given session_id."""
         sm = self.session_manager
         try:
             await sm.delete_session(session_id)
