@@ -4,11 +4,13 @@ import unittest.mock as mock
 import pytest
 from jupyter_core.paths import jupyter_config_path
 
-from jupyter_server.extension.manager import ExtensionManager
-from jupyter_server.extension.manager import ExtensionMetadataError
-from jupyter_server.extension.manager import ExtensionModuleNotFound
-from jupyter_server.extension.manager import ExtensionPackage
-from jupyter_server.extension.manager import ExtensionPoint
+from jupyter_server.extension.manager import (
+    ExtensionManager,
+    ExtensionMetadataError,
+    ExtensionModuleNotFound,
+    ExtensionPackage,
+    ExtensionPoint,
+)
 
 # Use ServerApps environment because it monkeypatches
 # jupyter_core.paths and provides a config directory
@@ -94,39 +96,51 @@ def test_extension_manager_linked_extensions(jp_serverapp):
     assert name in manager.linked_extensions
 
 
-def test_extension_manager_fail_add(jp_serverapp):
+@pytest.mark.parametrize("has_app", [True, False])
+def test_extension_manager_fail_add(jp_serverapp, has_app):
     name = "tests.extension.notanextension"
-    manager = ExtensionManager(serverapp=jp_serverapp)
+    manager = ExtensionManager(serverapp=jp_serverapp if has_app else None)
     manager.add_extension(name, enabled=True)  # should only warn
     jp_serverapp.reraise_server_extension_failures = True
-    with pytest.raises(ExtensionModuleNotFound):
-        manager.add_extension(name, enabled=True)
+    if has_app:
+        with pytest.raises(ExtensionModuleNotFound):
+            assert manager.add_extension(name, enabled=True) is False
+    else:
+        assert manager.add_extension(name, enabled=True) is False
 
 
-def test_extension_manager_fail_link(jp_serverapp):
+@pytest.mark.parametrize("has_app", [True, False])
+def test_extension_manager_fail_link(jp_serverapp, has_app):
     name = "tests.extension.mockextensions.app"
     with mock.patch(
         "tests.extension.mockextensions.app.MockExtensionApp.parse_command_line",
         side_effect=RuntimeError,
     ):
-        manager = ExtensionManager(serverapp=jp_serverapp)
+        manager = ExtensionManager(serverapp=jp_serverapp if has_app else None)
         manager.add_extension(name, enabled=True)
         manager.link_extension(name)  # should only warn
         jp_serverapp.reraise_server_extension_failures = True
-        with pytest.raises(RuntimeError):
+        if has_app:
+            with pytest.raises(RuntimeError):
+                manager.link_extension(name)
+        else:
             manager.link_extension(name)
 
 
-def test_extension_manager_fail_load(jp_serverapp):
+@pytest.mark.parametrize("has_app", [True, False])
+def test_extension_manager_fail_load(jp_serverapp, has_app):
     name = "tests.extension.mockextensions.app"
     with mock.patch(
         "tests.extension.mockextensions.app.MockExtensionApp.initialize_handlers",
         side_effect=RuntimeError,
     ):
-        manager = ExtensionManager(serverapp=jp_serverapp)
+        manager = ExtensionManager(serverapp=jp_serverapp if has_app else None)
         manager.add_extension(name, enabled=True)
         manager.link_extension(name)
         manager.load_extension(name)  # should only warn
         jp_serverapp.reraise_server_extension_failures = True
-        with pytest.raises(RuntimeError):
+        if has_app:
+            with pytest.raises(RuntimeError):
+                manager.load_extension(name)
+        else:
             manager.load_extension(name)
