@@ -14,6 +14,7 @@ from unittest.mock import MagicMock, patch
 
 import pytest
 import tornado
+from jupyter_core.utils import ensure_async
 from tornado.httpclient import HTTPRequest, HTTPResponse
 from tornado.web import HTTPError
 from traitlets import Int, Unicode
@@ -21,7 +22,6 @@ from traitlets.config import Config
 
 from jupyter_server.gateway.gateway_client import GatewayTokenRenewerBase, NoOpTokenRenewer
 from jupyter_server.gateway.managers import ChannelQueue, GatewayClient, GatewayKernelManager
-from jupyter_server.utils import ensure_async
 
 from .utils import expected_http_error
 
